@@ -49,7 +49,7 @@ test_opts = [
     cfg.StrOpt('sqlite_clean_db',
                default='clean.sqlite',
                help='File name of clean sqlite db'),
-    ]
+]
 
 CONF = cfg.CONF
 CONF.register_opts(test_opts)
@@ -66,8 +66,8 @@ _DB_CACHE = None
 
 class Database(fixtures.Fixture):
 
-    def __init__(self, db_session, db_migrate, sql_connection,
-                    sqlite_db, sqlite_clean_db):
+    def __init__(self, db_session, db_migrate, sql_connection, sqlite_db,
+                 sqlite_clean_db):
         self.sql_connection = sql_connection
         self.sqlite_db = sqlite_db
         self.sqlite_clean_db = sqlite_clean_db
@@ -176,10 +176,12 @@ class TestCase(testtools.TestCase, unittest2.TestCase):
 
         global _DB_CACHE
         if not _DB_CACHE:
-            _DB_CACHE = Database(session, migration,
-                                    sql_connection=CONF.database.connection,
-                                    sqlite_db=CONF.sqlite_db,
-                                    sqlite_clean_db=CONF.sqlite_clean_db)
+            _DB_CACHE = Database(
+                session, migration,
+                sql_connection=CONF.database.connection,
+                sqlite_db=CONF.sqlite_db,
+                sqlite_clean_db=CONF.sqlite_clean_db
+            )
         self.useFixture(_DB_CACHE)
 
         mox_fixture = self.useFixture(MoxStubout())
@@ -204,11 +206,9 @@ class TestCase(testtools.TestCase, unittest2.TestCase):
             CONF.set_override(k, v, group)
 
     def path_get(self, project_file=None):
-        root = os.path.abspath(os.path.join(os.path.dirname(__file__),
-            '..',
-            '..',
-            )
-            )
+        root = os.path.abspath(
+            os.path.join(os.path.dirname(__file__), '..', '..',))
+
         if project_file:
             return os.path.join(root, project_file)
         else:
